@@ -61,7 +61,7 @@ static integer Permutation_checkRange (Permutation me, integer *from, integer *t
 
 void Permutation_checkInvariant (Permutation me) {
 	autoPermutation thee = Data_copy (me);
-	NUMsort_integer (thy numberOfElements, thy p.at);
+	INTVECsort_inplace (thy p.all());
 	for (integer i = 1; i <= my numberOfElements; i ++)
 		Melder_require (thy p [i] == i,
 			me, U": is not a valid permutation.");
@@ -172,11 +172,11 @@ void Permutation_swapBlocks (Permutation me, integer from, integer to, integer b
 
 void Permutation_permuteRandomly_inplace (Permutation me, integer from, integer to) {
 	try {
-		integer n = Permutation_checkRange (me, & from, & to);
+		const integer n = Permutation_checkRange (me, & from, & to);
 		if (n == 1)
 			return;
 		for (integer i = from; i < to; i ++) {
-			integer newpos = NUMrandomInteger (from, to);
+			const integer newpos = NUMrandomInteger (from, to);
 			std::swap (my p [i], my p [newpos]);
 		}
 	} catch (MelderError) {
@@ -196,7 +196,7 @@ autoPermutation Permutation_permuteRandomly (Permutation me, integer from, integ
 
 autoPermutation Permutation_rotate (Permutation me, integer from, integer to, integer step) {
 	try {
-		integer n = Permutation_checkRange (me, & from, & to);
+		const integer n = Permutation_checkRange (me, & from, & to);
 		step = (step - 1) % n + 1;
 
 		autoPermutation thee = Data_copy (me);
@@ -216,7 +216,7 @@ autoPermutation Permutation_rotate (Permutation me, integer from, integer to, in
 
 void Permutation_swapOneFromRange (Permutation me, integer from, integer to, integer pos, bool forbidsame) {
 	try {
-		integer n = Permutation_checkRange (me, & from, & to);
+		const integer n = Permutation_checkRange (me, & from, & to);
 		integer newpos = NUMrandomInteger (from, to);
 		if (newpos == pos && forbidsame) {
 			Melder_require (n != 1,
@@ -234,7 +234,7 @@ void Permutation_swapOneFromRange (Permutation me, integer from, integer to, int
 
 autoPermutation Permutation_permuteBlocksRandomly (Permutation me, integer from, integer to, integer blockSize, bool permuteWithinBlocks, bool noDoublets) {
 	try {
-		integer n = Permutation_checkRange (me, & from, & to);
+		const integer n = Permutation_checkRange (me, & from, & to);
 		if (blockSize == 1 || (blockSize >= n && permuteWithinBlocks)) {
 			autoPermutation thee = Permutation_permuteRandomly (me, from, to);
 			return thee;
@@ -243,7 +243,7 @@ autoPermutation Permutation_permuteBlocksRandomly (Permutation me, integer from,
 		if (blockSize >= n)
 			return thee;
 
-		integer nblocks  = n / blockSize, nrest = n % blockSize;
+		const integer nblocks  = n / blockSize, nrest = n % blockSize;
 		Melder_require (nrest == 0,
 			U"There should fit an integer number of blocks in the range.\n(The last block is only of size ", nrest, U").");
 		
@@ -253,13 +253,13 @@ autoPermutation Permutation_permuteBlocksRandomly (Permutation me, integer from,
 		integer first = from;
 		for (integer iblock = 1; iblock <= nblocks; iblock ++, first += blockSize) {
 			/* (n1,n2,n3,...) means: move block n1 to position 1 etc... */
-			integer blocktomove = Permutation_getValueAtIndex (pblocks.get(), iblock);
+			const integer blocktomove = Permutation_getValueAtIndex (pblocks.get(), iblock);
 
 			for (integer j = 1; j <= blockSize; j ++)
 				thy p [first - 1 + j] = my p [from - 1 + (blocktomove - 1) * blockSize + j];
 
 			if (permuteWithinBlocks) {
-				integer last = first + blockSize - 1;
+				const integer last = first + blockSize - 1;
 				Permutation_permuteRandomly_inplace (thee.get(), first, last);
 				if (noDoublets && iblock > 0 && thy p [first - 1] % blockSize == thy p [first] % blockSize)
 					Permutation_swapOneFromRange (thee.get(), first + 1, last, first, 0);
@@ -275,8 +275,8 @@ autoPermutation Permutation_interleave (Permutation me, integer from, integer to
 	try {
 		Melder_require (offset < blockSize,
 			U"Offset should be smaller than block size.");
-		integer n = Permutation_checkRange (me, & from, & to);
-		integer nblocks = n / blockSize, nrest = n % blockSize;
+		const integer n = Permutation_checkRange (me, & from, & to);
+		const integer nblocks = n / blockSize, nrest = n % blockSize;
 		Melder_require (nrest == 0,
 			U"There should fit an integer number of blocks in the range.\n"
 			U"(The last block is only of size ", nrest, U" instead of ", blockSize, U").");
@@ -284,11 +284,11 @@ autoPermutation Permutation_interleave (Permutation me, integer from, integer to
 		autoPermutation thee = Data_copy (me);
 
 		if (nblocks > 1) {
-			autoNUMvector<integer> occupied (1, blockSize);
+			autoBOOLVEC occupied = newBOOLVECzero (blockSize);
 
 			integer posinblock = 1 - offset;
 			for (integer i = 1; i <= n; i ++) {
-				integer index, rblock = (i - 1) % nblocks + 1;
+				const integer rblock = (i - 1) % nblocks + 1;
 
 				posinblock += offset;
 				if (posinblock > blockSize)
@@ -296,15 +296,15 @@ autoPermutation Permutation_interleave (Permutation me, integer from, integer to
 
 				if (i % nblocks == 1) {
 					integer count = blockSize;
-					while (occupied [posinblock] == 1 && count > 0) {
+					while (occupied [posinblock] && count > 0) {
 						posinblock ++;
 						count --;
 						if (posinblock > blockSize)
 							posinblock -= blockSize;
 					}
-					occupied [posinblock] = 1;
+					occupied [posinblock] = true;
 				}
-				index = from - 1 + (rblock - 1) * blockSize + posinblock;
+				const integer index = from - 1 + (rblock - 1) * blockSize + posinblock;
 				thy p [from - 1 + i] = my p [index];
 			}
 		}
@@ -338,7 +338,7 @@ autoPermutation Permutation_invert (Permutation me) {
 }
 
 void Permutation_reverse_inline (Permutation me, integer from, integer to) {
-	integer n = Permutation_checkRange (me, & from, & to);
+	const integer n = Permutation_checkRange (me, & from, & to);
 	for (integer i = 1; i <= n / 2; i ++)
 		std::swap (my p [from + i - 1], my p [to - i + 1] );
 }
@@ -358,7 +358,7 @@ autoPermutation Permutation_reverse (Permutation me, integer from, integer to) {
    Adapted from the GSL library
 */
 void Permutation_next_inplace (Permutation me) {
-	integer size = my numberOfElements;
+	const integer size = my numberOfElements;
 	Melder_require (size > 1,
 		U"The permutation should have more than one element.");
 
@@ -382,7 +382,7 @@ void Permutation_next_inplace (Permutation me) {
    Adapted from the GSL library
 */
 void Permutation_previous_inplace (Permutation me) {
-	integer size = my numberOfElements;
+	const integer size = my numberOfElements;
 	Melder_require (size > 1,
 		U"The permutation should have more than one element.");
 
@@ -418,8 +418,8 @@ autoPermutation Permutations_multiply2 (Permutation me, Permutation thee) {
 
 autoPermutation Permutations_multiply (OrderedOf<structPermutation>* me) {
 	try {
-	Melder_require (my size > 1,
-		U"There should be at least two Permutations to multiply.");
+		Melder_require (my size > 1,
+			U"There should be at least two Permutations to multiply.");
 		autoPermutation thee = Permutations_multiply2 (my at [1], my at [2]);
 		for (integer i = 3; i <= my size; i ++) {
 			autoPermutation him = Permutations_multiply2 (thee.get(), my at [i]);
