@@ -4,7 +4,7 @@
  *
  * Multi Dimensional Scaling
  *
- * Copyright (C) 1993-2018 David Weenink, 2015,2017,2018 Paul Boersma
+ * Copyright (C) 1993-2019 David Weenink, 2015,2017,2018 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,34 +25,6 @@
  djmw 20110306 Latest modification.
 */
 
-#define KRUSKAL_MAXDIMENSION 10
-
-/* process */
-#define MDS_DISCRETE 0
-#define MDS_CONTINUOUS 1
-
-/* measurement conditionality */
-#define MDS_UNCONDITIONAL 0
-#define MDS_MATRIXCONDITIONAL 1
-#define MDS_ROWCONDITIONAL 2
-
-/* normalization */
-#define CONFIGURATION_COLUMNS 1
-#define CONFIGURATION_MATRIX 2
-
-/* ties processing */
-#define MDS_PRIMARY_APPROACH 1
-#define MDS_SECONDARY_APPROACH 2
-
-/* stress */
-#define MDS_NORMALIZED_STRESS 1
-#define MDS_STRESS_1 2
-#define MDS_STRESS_2 3
-#define MDS_RAW_STRESS 4
-
-#define MDS_MSPLINE 1
-#define MDS_ISPLINE 2
-
 #include "Graphics.h"
 #include "Minimizers.h"
 #include "Confusion.h"
@@ -63,6 +35,7 @@
 #include "Distance.h"
 #include "Configuration.h"
 #include "SSCP.h"
+#include "MDS_enums.h"
 
 /************************** class Weight **************************************/
 
@@ -96,11 +69,6 @@ Collection_define (ConfusionList, OrderedOf, Confusion) {
 
 autoConfusion ConfusionList_sum (ConfusionList me);
 
-
-#pragma mark - class DistanceList
-
-
-
 #pragma mark - class ScalarProduct
 
 Thing_define (ScalarProduct, TableOfReal) {
@@ -108,7 +76,6 @@ Thing_define (ScalarProduct, TableOfReal) {
 
 autoScalarProduct ScalarProduct_create (integer numberOfPoints);
 
-
 #pragma mark - class ScalarProductList
 
 Collection_define (ScalarProductList, OrderedOf, ScalarProduct) {
@@ -160,7 +127,7 @@ Thing_define (RatioTransformator, Transformator) {
 autoRatioTransformator RatioTransformator_create (integer numberOfPoints);
 
 Thing_define (MonotoneTransformator, Transformator) {
-	int tiesHandling;
+	kMDS_TiesHandling tiesHandling;
 
 	autoDistance v_transform (MDSVec vec, Distance dist, Weight w)
 		override;
@@ -168,32 +135,37 @@ Thing_define (MonotoneTransformator, Transformator) {
 
 autoMonotoneTransformator MonotoneTransformator_create (integer numberPoints);
 
-void MonotoneTransformator_setTiesProcessing (MonotoneTransformator, int tiesHandling);
+void MonotoneTransformator_setTiesProcessing (MonotoneTransformator, kMDS_TiesHandling tiesHandling);
 
-
-/**************** class Similarity *****************************/
-
-
-
-/************** KRUSKAL *********************************************/
+/************** Kruskal *********************************************/
 
 Thing_define (Kruskal, Thing) {
-	int process;
-	int measurementLevel;
-	int conditionality;
 	autoConfiguration configuration;
 	autoProximityList proximities;
-	int stress_formula;
+	kMDS_TiesHandling tiesHandling;
+	kMDS_KruskalStress stress_formula;
 	autoMDSVec vec;
 	autoMAT dx;
 	autoMinimizer minimizer;
 };
 
-autoKruskal Kruskal_create (integer numberOfpoints, integer numberOfDimensions);
+autoKruskal Kruskal_create (integer numberOfPoints, integer numberOfDimensions);
+
+autoConfiguration Dissimilarity_to_Configuration_kruskal (Dissimilarity me,
+	integer numberOfDimensions, integer metric, kMDS_TiesHandling tiesHandling, kMDS_KruskalStress stress_formula,
+	double tolerance, integer numberOfIterations, integer numberOfRepetitions);
+
+autoConfiguration Dissimilarity_Configuration_kruskal (Dissimilarity me, Configuration him,
+	kMDS_TiesHandling tiesHandling, kMDS_KruskalStress stress_formula,
+	double tolerance, integer numberOfIterations, integer numberOfRepetitions);
+
+double Dissimilarity_Configuration_getStress (Dissimilarity me, Configuration him, kMDS_TiesHandling tiesHandling, kMDS_KruskalStress stress_formula);
+
+/******** end Kruskal **************************************************/
 
 double Dissimilarity_Configuration_Weight_Transformator_normalizedStress (Dissimilarity me, Configuration conf, Weight weight, Transformator t);
 
-double Distance_Weight_stress (Distance fit, Distance c, Weight w, int type);
+double Distance_Weight_stress (Distance fit, Distance c, Weight w, kMDS_stressMeasure type);
 /*
 	Calculates stress.
 	type is one of (MDS_NORMALIZED_STRESS, MDS_STRESS_1,
@@ -216,23 +188,22 @@ void Distance_Weight_rawStressComponents (Distance fit, Distance conf, Weight we
 		conf[i][j] = distance between x[i] and x[j] (in the configuration)
 */
 
-double Dissimilarity_Configuration_Transformator_Weight_stress (Dissimilarity d, Configuration c, Transformator t, Weight w,
-	int stressMeasure);
+double Dissimilarity_Configuration_Transformator_Weight_stress (Dissimilarity d, Configuration c, Transformator t, Weight w, kMDS_stressMeasure stressMeasure);
 
 double Dissimilarity_Configuration_Weight_absolute_stress (Dissimilarity d, Configuration c, Weight w,
-	int stressMeasure);
+	kMDS_stressMeasure stressMeasure);
 
 double Dissimilarity_Configuration_Weight_ratio_stress (Dissimilarity d, Configuration c, Weight w,
-	int stressMeasure);
+	kMDS_stressMeasure stressMeasure);
 
 double Dissimilarity_Configuration_Weight_interval_stress (Dissimilarity d, Configuration c, Weight w,
-	int stressMeasure);
+	kMDS_stressMeasure stressMeasure);
 
 double Dissimilarity_Configuration_Weight_monotone_stress (Dissimilarity d, Configuration c, Weight w,
-	int tiesHandling, int stressMeasure);
+	kMDS_TiesHandling tiesHandling, kMDS_stressMeasure stressMeasure);
 
 double Dissimilarity_Configuration_Weight_ispline_stress (Dissimilarity d, Configuration c, Weight w,
-	integer numberOfInteriorKnots, integer order, int stressMeasure);
+	integer numberOfInteriorKnots, integer order, kMDS_stressMeasure stressMeasure);
 
 void Distance_Weight_smacofNormalize (Distance d, Weight w);
 
@@ -251,7 +222,7 @@ autoConfiguration Dissimilarity_Configuration_Weight_ratio_mds (Dissimilarity di
 autoConfiguration Dissimilarity_Configuration_Weight_interval_mds (Dissimilarity dis, Configuration cstart, Weight w,
 	double tolerance, integer numberOfIterations, integer numberOfRepetitions, bool showProgress);
 
-autoConfiguration Dissimilarity_Configuration_Weight_monotone_mds (Dissimilarity dis, Configuration cstart, Weight w, int tiesHandling,
+autoConfiguration Dissimilarity_Configuration_Weight_monotone_mds (Dissimilarity dis, Configuration cstart, Weight w, kMDS_TiesHandling tiesHandling,
 	double tolerance, integer numberOfIterations, integer numberOfRepetitions, bool showProgress);
 
 autoConfiguration Dissimilarity_Configuration_Weight_ispline_mds (Dissimilarity me, Configuration cstart, Weight w,
@@ -268,7 +239,7 @@ autoConfiguration Dissimilarity_Weight_interval_mds (Dissimilarity dis, Weight w
 	integer numberOfDimensions, double tolerance, integer numberOfIterations, integer numberOfRepetitions, bool showProgress);
 
 autoConfiguration Dissimilarity_Weight_monotone_mds(Dissimilarity me, Weight w,
-	integer numberOfDimensions, int tiesHandling,
+	integer numberOfDimensions, kMDS_TiesHandling tiesHandling,
 	double tolerance, integer numberOfIterations, integer numberOfRepetitions, bool showProgress
 );
 
@@ -293,7 +264,7 @@ void Dissimilarity_Configuration_Weight_drawIntervalRegression (Dissimilarity d,
 );
 
 void Dissimilarity_Configuration_Weight_drawMonotoneRegression (Dissimilarity d, Configuration c, Weight w, Graphics g,
-	int tiesHandling, double xmin, double xmax, double ymin, double ymax,
+	kMDS_TiesHandling tiesHandling, double xmin, double xmax, double ymin, double ymax,
 	double size_mm, conststring32 mark, bool garnish
 );
 
@@ -342,27 +313,14 @@ autoConfiguration Distance_to_Configuration_torsca (Distance me, integer numberO
 
 /************** DISSIMILARITY & CONFIGURATION ************************/
 
-autoConfiguration Dissimilarity_to_Configuration_kruskal (Dissimilarity me,
-	integer numberOfDimensions, integer metric, int tiesHandling, int stress_formula,
-	double tolerance, integer numberOfIterations, integer numberOfRepetitions
-);
-
-autoConfiguration Dissimilarity_Configuration_kruskal (Dissimilarity me, Configuration him,
-	int tiesHandling, int stress_formula,
-	double tolerance, integer numberOfIterations, integer numberOfRepetitions
-);
-
-double Dissimilarity_Configuration_getStress (Dissimilarity me, Configuration him, int tiesHandling, int stress_formula);
-
 void Dissimilarity_Configuration_drawShepardDiagram (Dissimilarity me, Configuration him, Graphics g,
 	double xmin, double xmax, double ymin, double ymax, double size_mm, conststring32 mark, bool garnish);
 
-autoDistance Dissimilarity_Configuration_monotoneRegression (Dissimilarity dis, Configuration conf, int tiesHandling);
+autoDistance Dissimilarity_Configuration_monotoneRegression (Dissimilarity dis, Configuration conf, kMDS_TiesHandling tiesHandling);
 
-autoDistanceList DissimilarityList_Configuration_monotoneRegression (DissimilarityList dissims, Configuration conf, int tiesHandling);
+autoDistanceList DissimilarityList_Configuration_monotoneRegression (DissimilarityList dissims, Configuration conf, kMDS_TiesHandling tiesHandling);
 
-void Dissimilarity_Configuration_drawMonotoneRegression	(Dissimilarity me, Configuration him, Graphics g, int tiesHandling,
-	double xmin, double xmax, double ymin, double ymax, double size_mm, conststring32 mark, bool garnish);
+void Dissimilarity_Configuration_drawMonotoneRegression	(Dissimilarity me, Configuration him, Graphics g, kMDS_TiesHandling tiesHandling,	double xmin, double xmax, double ymin, double ymax, double size_mm, conststring32 mark, bool garnish);
 
 
 /************** SIMILARITY & TABLESOFREAL ********************************/
@@ -377,7 +335,7 @@ autoSimilarity ConfigurationList_to_Similarity_cc (ConfigurationList me, Weight
 autoDistance Dissimilarity_to_Distance (Dissimilarity me, int scale);
 /* with optional scaling with "additive constant" */
 
-autoDistance Dissimilarity_Distance_monotoneRegression (Dissimilarity me, Distance thee, int tiesHandling);
+autoDistance Dissimilarity_Distance_monotoneRegression (Dissimilarity me, Distance thee, kMDS_TiesHandling tiesHandling);
 
 
 /************** DISSIMILARITY & CONFUSION ************************************/
@@ -422,9 +380,9 @@ autoDistanceList ConfigurationList_to_DistanceList (ConfigurationList me);
 
 /************** MDSVec(Lists)  & Distance(List) **********************************/
 
-autoDistance MDSVec_Distance_monotoneRegression (MDSVec me, Distance thee, int tiesHandlingMethod);
+autoDistance MDSVec_Distance_monotoneRegression (MDSVec me, Distance thee, kMDS_TiesHandling tiesHandling);
 
-autoDistanceList MDSVecList_Distance_monotoneRegression (MDSVecList me, Distance thee, int tiesHandlingMethod);
+autoDistanceList MDSVecList_Distance_monotoneRegression (MDSVecList me, Distance thee, kMDS_TiesHandling tiesHandling);
 
 
 /************** ScalarProduct(List) & ...... **********************************/
@@ -443,23 +401,23 @@ void ScalarProductList_Configuration_Salience_indscal (ScalarProductList sp, Con
 
 /************** INDSCAL & ....... ***********************************/
 
-void DissimilarityList_indscal (DissimilarityList me, integer numberOfDimensions, int tiesHandlingMethod, bool normalizeScalarProducts,
+void DissimilarityList_indscal (DissimilarityList me, integer numberOfDimensions, kMDS_TiesHandling tiesHandling, bool normalizeScalarProducts,
 	double tolerance, integer numberOfIterations, integer numberOfRepetitions, bool showProgress, autoConfiguration *out1, autoSalience *out2);
 
 void DistanceList_to_Configuration_indscal (DistanceList me, integer numberOfDimensions, bool normalizeScalarProducts,
 	double tolerance, integer numberOfIterations, integer numberOfRepetitions, bool showProgress, autoConfiguration *out1, autoSalience *out2);
 
-void DissimilarityList_Configuration_indscal (DissimilarityList me, Configuration conf, int tiesHandlingMethod, bool normalizeScalarProducts,
+void DissimilarityList_Configuration_indscal (DissimilarityList me, Configuration conf, kMDS_TiesHandling tiesHandling, bool normalizeScalarProducts,
 	double tolerance, integer numberOfIterations, bool showProgress, autoConfiguration *out1, autoSalience *out2);
 
 void DistanceList_Configuration_indscal (DistanceList dists, Configuration conf, bool normalizeScalarProducts,
 	double tolerance, integer numberOfIterations, bool showProgress, autoConfiguration *out1, autoSalience *out2);
 
 void DissimilarityList_Configuration_Salience_indscal (DissimilarityList dissims, Configuration conf, Salience w,
-	int tiesHandlingMethod, bool normalizeScalarProducts,
+	kMDS_TiesHandling tiesHandling, bool normalizeScalarProducts,
 	double tolerance, integer numberOfIterations, bool showProgress, autoConfiguration *out1, autoSalience *out2, double *out_varianceAccountedFor);
 
-autoDistanceList MDSVecList_Configuration_Salience_monotoneRegression (MDSVecList vecs, Configuration conf, Salience weights, int tiesHandlingMethod);
+autoDistanceList MDSVecList_Configuration_Salience_monotoneRegression (MDSVecList vecs, Configuration conf, Salience weights, kMDS_TiesHandling tiesHandling);
 
 void DistanceList_Configuration_Salience_indscal (DistanceList dists, Configuration conf, Salience weights, bool normalizeScalarProducts,
 	double tolerance, integer numberOfIterations, bool showProgress, autoConfiguration *out1, autoSalience *out2, double *out_varianceAccountedFor);
@@ -467,19 +425,19 @@ void DistanceList_Configuration_Salience_indscal (DistanceList dists, Configurat
 void DistanceList_Configuration_Salience_vaf (DistanceList me, Configuration thee, Salience him, bool normalizeScalarProducts, double *out_varianceAccountedFor);
 
 void DissimilarityList_Configuration_Salience_vaf (DissimilarityList me, Configuration thee,
-	Salience him, int tiesHandlingMethod, bool normalizeScalarProducts, double *out_varianceAccountedFor);
+	Salience him, kMDS_TiesHandling tiesHandling, bool normalizeScalarProducts, double *out_varianceAccountedFor);
 
 void DistanceList_Configuration_vaf (DistanceList me, Configuration thee, bool normalizeScalarProducts, double *out_varianceAccountedFor);
 
 void DissimilarityList_Configuration_vaf (DissimilarityList me, Configuration thee,
-	int tiesHandlingMethod, bool normalizeScalarProducts, double *out_varianceAccountedFor);
+	kMDS_TiesHandling tiesHandling, bool normalizeScalarProducts, double *out_varianceAccountedFor);
 
 autoSalience ScalarProductList_Configuration_to_Salience (ScalarProductList me, Configuration him);
 
 autoSalience DistanceList_Configuration_to_Salience (DistanceList me, Configuration him, bool normalizeScalarProducts);
 
 autoSalience DissimilarityList_Configuration_to_Salience (DissimilarityList me, Configuration him,
-	int tiesHandling, bool normalizeScalarProducts);
+	kMDS_TiesHandling tiesHandling, bool normalizeScalarProducts);
 
 
 /********* Conversions from & to TableOfReal *****************************/
@@ -505,7 +463,7 @@ autoCollection INDSCAL_createCarrollWishExample (double noiseStd);
 
 autoSalience Salience_createCarrollWishExample ();
 
-void drawSplines (Graphics g, double low, double high, double ymin, double ymax, int type, integer order, char32 const *interiorKnots, bool garnish);
+void drawSplines (Graphics g, double low, double high, double ymin, double ymax, kMDS_splineType splineType, integer order, char32 const *interiorKnots, bool garnish);
 
 void drawMDSClassRelations (Graphics g);
 
