@@ -1,6 +1,6 @@
 /* MDSVec.cpp
  *
- * Copyright (C) 2018 David Weenink
+ * Copyright (C) 2018-2019 David Weenink
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -67,7 +67,7 @@ autoMDSVec Dissimilarity_to_MDSVec (Dissimilarity me) {
 		integer n = 0;
 		for (integer irow = 1; irow <= my numberOfRows - 1; irow ++) {
 			for (integer icol = irow + 1; icol <= my numberOfColumns; icol ++) {
-				double f = 0.5 * (my data [irow] [icol] + my data [icol] [irow]);
+				const double f = 0.5 * (my data [irow] [icol] + my data [icol] [irow]);
 				if (f > 0.0) {
 					n ++;
 					thy proximity [n] = f;
