@@ -88,8 +88,10 @@ double structMatrix :: v_getValueAtSample (integer isamp, integer ilevel, int un
 }
 
 double structMatrix :: v_getMatrix (integer irow, integer icol) {
-	if (irow < 1 || irow > our ny) return 0.0;
-	if (icol < 1 || icol > our nx) return 0.0;
+	if (irow < 1 || irow > our ny)
+		return 0.0;
+	if (icol < 1 || icol > our nx)
+		return 0.0;
 	return z [irow] [icol];
 }
 
@@ -134,8 +136,9 @@ autoMatrix Matrix_create
 autoMatrix Matrix_createSimple (integer numberOfRows, integer numberOfColumns) {
 	try {
 		autoMatrix me = Thing_new (Matrix);
-		Matrix_init (me.get(), 0.5, numberOfColumns + 0.5, numberOfColumns, 1, 1,
-			0.5, numberOfRows + 0.5, numberOfRows, 1, 1);
+		Matrix_init (me.get(),
+				0.5, numberOfColumns + 0.5, numberOfColumns, 1, 1,
+				0.5, numberOfRows    + 0.5, numberOfRows   , 1, 1);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"Matrix object not created.");
@@ -165,36 +168,46 @@ integer Matrix_yToNearestRow (Matrix me, double y) { return Melder_iround (Matri
 integer Matrix_getWindowSamplesX (Matrix me, double xmin, double xmax, integer *ixmin, integer *ixmax) {
 	*ixmin = 1 + Melder_iceiling ((xmin - my x1) / my dx);
 	*ixmax = 1 + Melder_ifloor   ((xmax - my x1) / my dx);
-	if (*ixmin < 1) *ixmin = 1;
-	if (*ixmax > my nx) *ixmax = my nx;
-	if (*ixmin > *ixmax) return 0;
+	if (*ixmin < 1)
+		*ixmin = 1;
+	if (*ixmax > my nx)
+		*ixmax = my nx;
+	if (*ixmin > *ixmax)
+		return 0;
 	return *ixmax - *ixmin + 1;
 }
 
 integer Matrix_getWindowSamplesY (Matrix me, double ymin, double ymax, integer *iymin, integer *iymax) {
 	*iymin = 1 + Melder_iceiling ((ymin - my y1) / my dy);
 	*iymax = 1 + Melder_ifloor   ((ymax - my y1) / my dy);
-	if (*iymin < 1) *iymin = 1;
-	if (*iymax > my ny) *iymax = my ny;
-	if (*iymin > *iymax) return 0;
+	if (*iymin < 1)
+		*iymin = 1;
+	if (*iymax > my ny)
+		*iymax = my ny;
+	if (*iymin > *iymax)
+		return 0;
 	return *iymax - *iymin + 1;
 }
 
 integer Matrix_getWindowExtrema (Matrix me, integer ixmin, integer ixmax, integer iymin, integer iymax,
 	double *minimum, double *maximum)
 {
-	if (ixmin == 0) ixmin = 1;
-	if (ixmax == 0) ixmax = my nx;
-	if (iymin == 0) iymin = 1;
-	if (iymax == 0) iymax = my ny;
-	if (ixmin > ixmax || iymin > iymax) return 0;
-	*minimum = *maximum = my z [iymin] [ixmin];
-	for (integer iy = iymin; iy <= iymax; iy ++) {
-		for (integer ix = ixmin; ix <= ixmax; ix ++) {
-			if (my z [iy] [ix] < *minimum) *minimum = my z [iy] [ix];
-			if (my z [iy] [ix] > *maximum) *maximum = my z [iy] [ix];
-		}
-	}
+	if (ixmin == 0)
+		ixmin = 1;
+	if (ixmax == 0)
+		ixmax = my nx;
+	if (iymin == 0)
+		iymin = 1;
+	if (iymax == 0)
+		iymax = my ny;
+	if (ixmin > ixmax || iymin > iymax)
+		return 0;
+	MelderExtremaWithInit extrema;
+	for (integer iy = iymin; iy <= iymax; iy ++)
+		for (integer ix = ixmin; ix <= ixmax; ix ++)
+			extrema.update (my z [iy] [ix]);
+	*minimum = extrema.min;
+	*maximum = extrema.max;
 	return (ixmax - ixmin + 1) * (iymax - iymin + 1);
 }
 
@@ -205,8 +218,10 @@ double Matrix_getValueAtXY (Matrix me, double x, double y) {
 	 * We imagine a unit square around every (xi, yi) point in the matrix.
 	 * For (x, y) values outside the union of these squares, the z value is undefined.
 	 */
-	if (row_real < 0.5 || row_real > my ny + 0.5) return undefined;
-	if (col_real < 0.5 || col_real > my nx + 0.5) return undefined;
+	if (row_real < 0.5 || row_real > my ny + 0.5)
+		return undefined;
+	if (col_real < 0.5 || col_real > my nx + 0.5)
+		return undefined;
 	/*
 	 * Determine the four nearest (xi, yi) points.
 	 */
@@ -224,10 +239,14 @@ double Matrix_getValueAtXY (Matrix me, double x, double y) {
 	 * If not, we do constant extrapolation,
 	 * which can be simulated by an interpolation between equal z values.
 	 */
-	if (bottomRow < 1) bottomRow = 1;         // 1 <= bottomRow <= my ny
-	if (topRow > my ny) topRow = my ny;       // 1 <= topRow <= my ny
-	if (leftCol < 1) leftCol = 1;             // 1 <= leftCol <= my nx
-	if (rightCol > my nx) rightCol = my nx;   // 1 <= rightCol <= my nx
+	if (bottomRow < 1)
+		bottomRow = 1;         // 1 <= bottomRow <= my ny
+	if (topRow > my ny)
+		topRow = my ny;        // 1 <= topRow <= my ny
+	if (leftCol < 1)
+		leftCol = 1;           // 1 <= leftCol <= my nx
+	if (rightCol > my nx)
+		rightCol = my nx;      // 1 <= rightCol <= my nx
 	return (1.0 - drow) * (1.0 - dcol) * my z [bottomRow] [leftCol] +
 		drow * (1.0 - dcol) * my z [topRow] [leftCol] +
 		(1.0 - drow) * dcol * my z [bottomRow] [rightCol] +
@@ -245,22 +264,29 @@ double Matrix_getNorm (Matrix me) {
 void Matrix_drawRows (Matrix me, Graphics g, double xmin, double xmax, double ymin, double ymax,
 	double minimum, double maximum)
 {
-	if (xmax <= xmin) { xmin = my xmin; xmax = my xmax; }
-	if (ymax <= ymin) { ymin = my ymin; ymax = my ymax; }
+	Function_unidirectionalAutowindow (me, & xmin, & xmax);
+	if (ymax <= ymin) {
+		ymin = my ymin;
+		ymax = my ymax;
+	}
 	integer ixmin, ixmax, iymin, iymax;
 	(void) Matrix_getWindowSamplesX (me, xmin, xmax, & ixmin, & ixmax);
 	(void) Matrix_getWindowSamplesY (me, ymin, ymax, & iymin, & iymax);
 	if (maximum <= minimum)
 		(void) Matrix_getWindowExtrema (me, ixmin, ixmax, iymin, iymax, & minimum, & maximum);
-	if (maximum <= minimum) { minimum -= 1.0; maximum += 1.0; }
-	if (xmin >= xmax) return;
+	if (maximum <= minimum) {
+		minimum -= 1.0;
+		maximum += 1.0;
+	}
+	if (xmin >= xmax)
+		return;
 	Graphics_setInner (g);
 	for (integer iy = iymin; iy <= iymax; iy ++) {
 		Graphics_setWindow (g, xmin, xmax,
-			minimum - (iy - iymin) * (maximum - minimum),
-			maximum + (iymax - iy) * (maximum - minimum));
+				minimum - (iy - iymin) * (maximum - minimum),
+				maximum + (iymax - iy) * (maximum - minimum));
 		Graphics_function (g, & my z [iy] [0], ixmin, ixmax,
-			Matrix_columnToX (me, ixmin), Matrix_columnToX (me, ixmax));
+				Matrix_columnToX (me, ixmin), Matrix_columnToX (me, ixmax));
 	}
 	Graphics_unsetInner (g);
 	if (iymin < iymax)
@@ -318,7 +344,7 @@ void Matrix_paintContours (Matrix me, Graphics g, double xmin, double xmax, doub
 	double minimum, double maximum)
 {
 	double border [1 + 30];
-	if (xmax <= xmin) { xmin = my xmin; xmax = my xmax; }
+	Function_unidirectionalAutowindow (me, & xmin, & xmax);
 	if (ymax <= ymin) { ymin = my ymin; ymax = my ymax; }
 	integer ixmin, ixmax, iymin, iymax;
 	(void) Matrix_getWindowSamplesX (me, xmin, xmax, & ixmin, & ixmax);
@@ -342,7 +368,7 @@ void Matrix_paintContours (Matrix me, Graphics g, double xmin, double xmax, doub
 static void cellArrayOrImage (Matrix me, Graphics g, double xmin, double xmax, double ymin, double ymax,
 	double minimum, double maximum, bool interpolate)
 {
-	if (xmax <= xmin) { xmin = my xmin; xmax = my xmax; }
+	Function_unidirectionalAutowindow (me, & xmin, & xmax);
 	if (ymax <= ymin) { ymin = my ymin; ymax = my ymax; }
 	integer ixmin, ixmax, iymin, iymax;
 	(void) Matrix_getWindowSamplesX (me, xmin - 0.49999 * my dx, xmax + 0.49999 * my dx,
@@ -384,7 +410,7 @@ void Matrix_paintCells (Matrix me, Graphics g, double xmin, double xmax, double
 void Matrix_paintSurface (Matrix me, Graphics g, double xmin, double xmax, double ymin, double ymax,
 	double minimum, double maximum, double elevation, double azimuth)
 {
-	if (xmax <= xmin) { xmin = my xmin; xmax = my xmax; }
+	Function_unidirectionalAutowindow (me, & xmin, & xmax);
 	if (ymax <= ymin) { ymin = my ymin; ymax = my ymax; }
 	integer ixmin, ixmax, iymin, iymax;
 	(void) Matrix_getWindowSamplesX (me, xmin, xmax, & ixmin, & ixmax);
@@ -413,7 +439,7 @@ void Matrix_playMovie (Matrix me, Graphics g) {
 	}
 	for (integer icol = 1; icol <= my nx; icol ++) {
 		column.all() <<= my z.column (icol);
-		Graphics_beginMovieFrame (g, & Graphics_WHITE);
+		Graphics_beginMovieFrame (g, & Melder_WHITE);
 		Graphics_setWindow (g, my ymin, my ymax, minimum, maximum);
 		Graphics_function (g, column.at, 1, my ny, my ymin, my ymax);
 		Graphics_endMovieFrame (g, 0.03);
@@ -426,7 +452,7 @@ autoMatrix Matrix_readAP (MelderFile file) {
 		int16 header [256];
 		for (integer i = 0; i < 256; i ++)
 			header [i] = bingeti16LE (f);
-		double samplingFrequency = header [100];   // converting up (from 16 to 54 bytes)
+		const double samplingFrequency = double (header [100]);   // converting up (from 16 to 54 bytes)
 		Melder_casual (U"Sampling frequency ", samplingFrequency);
 		autoMatrix me = Matrix_create (0.0, (double) header [34], header [34] /* Number of frames. */, 1.0, 0.5,
 			0.0, (double) header [35], header [35] /* Number of words per frame. */, 1.0, 0.5);
@@ -442,8 +468,8 @@ autoMatrix Matrix_readAP (MelderFile file) {
 				my z [j] [i] = bingeti16LE (f);   // converting up (from 16 to 54 bytes)
 
 		/*
-		 * Get pitch frequencies.
-		 */
+			Get pitch frequencies.
+		*/
 		for (integer i = 1; i <= my nx; i ++)
 			if (my z [1] [i] != 0.0)
 				my z [1] [i] = - samplingFrequency / my z [1] [i];
@@ -458,10 +484,14 @@ autoMatrix Matrix_readAP (MelderFile file) {
 autoMatrix Matrix_appendRows (Matrix me, Matrix thee, ClassInfo klas) {
 	try {
 		autoMatrix him = Thing_newFromClass (klas).static_cast_move<structMatrix>();
-		Matrix_init (him.get(), my xmin < thy xmin ? my xmin : thy xmin,
-			my xmax > thy xmax ? my xmax : thy xmax,
-			my nx > thy nx ? my nx : thy nx, my dx, my x1 < thy x1 ? my x1 : thy x1,
-			my ymin, my ymax + (thy ymax - thy ymin), my ny + thy ny, my dy, my y1);
+		Matrix_init (him.get(),
+			std::min (my xmin, thy xmin),
+			std::max (my xmax, thy xmax),
+			std::max (my nx, thy nx),
+			my dx,
+			std::min (my x1, thy x1),
+			my ymin, my ymax + (thy ymax - thy ymin), my ny + thy ny, my dy, my y1
+		);
 		for (integer irow = 1; irow <= my ny; irow ++)
 			for (integer icol = 1; icol <= my nx; icol ++)
 				his z [irow] [icol] = my z [irow] [icol];
@@ -540,7 +570,7 @@ autoMatrix Matrix_readFromRawTextFile (MelderFile file) {   // BUG: not Unicode-
 void Matrix_eigen (Matrix me, autoMatrix *out_eigenvectors, autoMatrix *out_eigenvalues) {
 	try {
 		Melder_require (my nx == my ny, 
-			U"The number of rows and the number of columns must be equal.");
+			U"The number of rows (here ", my ny, U") should be equal to the number of columns (here ", my nx, U").");
 		autoEigen eigen = Thing_new (Eigen);
 		Eigen_initFromSymmetricMatrix (eigen.get(), my z.get());
 		autoMatrix eigenvectors = Data_copy (me);
@@ -559,8 +589,8 @@ void Matrix_eigen (Matrix me, autoMatrix *out_eigenvectors, autoMatrix *out_eige
 
 autoMatrix Matrix_power (Matrix me, integer power) {
 	try {
-		if (my nx != my ny)
-			Melder_throw (U"Matrix not square.");
+		Melder_require (my nx == my ny,
+			U"The number of rows (here ", my ny, U") should be equal to the number of columns (here ", my nx, U").");
 		autoMatrix thee = Data_copy (me);
 		autoMatrix him = Data_copy (me);
 		for (integer ipow = 2; ipow <= power; ipow ++) {
@@ -639,10 +669,7 @@ void Matrix_formula_part (Matrix me, double xmin, double xmax, double ymin, doub
 	conststring32 expression, Interpreter interpreter, Matrix target)
 {
 	try {
-		if (xmax <= xmin) {
-			xmin = my xmin;
-			xmax = my xmax;
-		}
+		Function_unidirectionalAutowindow (me, & xmin, & xmax);
 		if (ymax <= ymin) {
 			ymin = my ymin;
 			ymax = my ymax;
