@@ -138,9 +138,9 @@ extern "C" Graphics Movie_create (conststring32 title, int width, int height) {
 	return theMovieGraphics.get();
 }
 
-DIRECT (MOVIE_Matrix_movie) {
+DIRECT (MOVIE_Matrix_playMovie) {
 	MOVIE_ONE (Matrix, U"Matrix movie", 300, 300)
-		Matrix_movie (me, graphics);
+		Matrix_playMovie (me, graphics);
 	MOVIE_ONE_END
 }
 
@@ -355,6 +355,23 @@ DIRECT (REAL_Matrix_getSum) {
 	NUMBER_ONE_END (U" (sum)");
 }
 
+DIRECT (NUMMAT_Matrix_getAllValues) {
+	NUMMAT_ONE (Matrix)
+		autoMAT result = newMATcopy (my z.all());
+	NUMMAT_ONE_END
+}
+
+FORM (NUMVEC_Matrix_getAllValuesInRow, U"Get all values in row", nullptr) {
+	NATURAL (rowNumber, U"Row number", U"1")
+	OK
+DO
+	NUMVEC_ONE (Matrix)
+		Melder_require (rowNumber <= my ny,
+			U"The row number (", rowNumber, U") should not be greater than the number of rows (", my ny, U").");
+		autoVEC result = newVECcopy (my z.row (rowNumber));
+	NUMVEC_ONE_END
+}
+
 // MARK: Modify
 
 FORM (MODIFY_Matrix_formula, U"Matrix Formula", U"Formula...") {
@@ -805,7 +822,7 @@ void praat_Matrix_init () {
 	praat_addAction1 (classMatrix, 1,   U"Write to matrix text file...", U"*Save as matrix text file...", praat_DEPRECATED_2011, SAVE_Matrix_writeToMatrixTextFile);
 	praat_addAction1 (classMatrix, 1, U"Save as headerless spreadsheet file...", nullptr, 0, SAVE_Matrix_writeToHeaderlessSpreadsheetFile);
 	praat_addAction1 (classMatrix, 1,   U"Write to headerless spreadsheet file...", nullptr, praat_DEPRECATED_2011, SAVE_Matrix_writeToHeaderlessSpreadsheetFile);
-	praat_addAction1 (classMatrix, 1, U"Play movie", nullptr, 0, MOVIE_Matrix_movie);
+	praat_addAction1 (classMatrix, 1, U"Play movie", nullptr, 0, MOVIE_Matrix_playMovie);
 	praat_addAction1 (classMatrix, 0, U"Draw -", nullptr, 0, nullptr);
 		praat_addAction1 (classMatrix, 0, U"Draw rows...", nullptr, 1, GRAPHICS_Matrix_drawRows);
 		praat_addAction1 (classMatrix, 0, U"Draw one contour...", nullptr, 1, GRAPHICS_Matrix_drawOneContour);
@@ -829,6 +846,8 @@ void praat_Matrix_init () {
 		praat_addAction1 (classMatrix, 1, U"-- get value --", nullptr, 1, nullptr);
 		praat_addAction1 (classMatrix, 1, U"Get value in cell...", nullptr, 1, REAL_Matrix_getValueInCell);
 		praat_addAction1 (classMatrix, 1, U"Get value at xy...", nullptr, 1, REAL_Matrix_getValueAtXY);
+		praat_addAction1 (classMatrix, 1, U"Get all values", nullptr, 1, NUMMAT_Matrix_getAllValues);
+		praat_addAction1 (classMatrix, 1, U"Get all values in row...", nullptr, 1, NUMVEC_Matrix_getAllValuesInRow);
 		praat_addAction1 (classMatrix, 1, U"Get minimum", nullptr, 1, REAL_Matrix_getMinimum);
 		praat_addAction1 (classMatrix, 1, U"Get maximum", nullptr, 1, REAL_Matrix_getMaximum);
 		praat_addAction1 (classMatrix, 1, U"Get sum", nullptr, 1, REAL_Matrix_getSum);
