@@ -1,6 +1,6 @@
 /* Network.cpp
  *
- * Copyright (C) 2009,2011-2017 Paul Boersma
+ * Copyright (C) 2009,2011-2019 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -92,9 +92,9 @@ void Network_init (Network me, double spreadingRate, kNetwork_activityClippingRu
 	my ymin = ymin;
 	my ymax = ymax;
 	my numberOfNodes = numberOfNodes;
-	my nodes = NUMvector <structNetworkNode> (1, numberOfNodes);
+	my nodes = newvectorzero <structNetworkNode> (numberOfNodes);
 	my numberOfConnections = numberOfConnections;
-	my connections = NUMvector <structNetworkConnection> (1, numberOfConnections);
+	my connections = newvectorzero <structNetworkConnection> (numberOfConnections);
 }
 
 autoNetwork Network_create (double spreadingRate, kNetwork_activityClippingRule activityClippingRule,
@@ -115,8 +115,8 @@ autoNetwork Network_create (double spreadingRate, kNetwork_activityClippingRule
 
 double Network_getActivity (Network me, integer nodeNumber) {
 	try {
-		if (nodeNumber <= 0 || nodeNumber > my numberOfNodes)
-			Melder_throw (me, U": node number (", nodeNumber, U") out of the range 1..", my numberOfNodes, U".");
+		Melder_require (nodeNumber >= 1 && nodeNumber <= my numberOfNodes,
+			me, U": node number (", nodeNumber, U") out of the range 1..", my numberOfNodes, U".");
 		return my nodes [nodeNumber]. activity;
 	} catch (MelderError) {
 		Melder_throw (me, U": activity not gotten.");
@@ -125,8 +125,8 @@ double Network_getActivity (Network me, integer nodeNumber) {
 
 void Network_setActivity (Network me, integer nodeNumber, double activity) {
 	try {
-		if (nodeNumber <= 0 || nodeNumber > my numberOfNodes)
-			Melder_throw (me, U": node number (", nodeNumber, U") out of the range 1..", my numberOfNodes, U".");
+		Melder_require (nodeNumber >= 1 && nodeNumber <= my numberOfNodes,
+			me, U": node number (", nodeNumber, U") out of the range 1..", my numberOfNodes, U".");
 		my nodes [nodeNumber]. activity = my nodes [nodeNumber]. excitation = activity;
 	} catch (MelderError) {
 		Melder_throw (me, U": activity not set.");
@@ -135,8 +135,8 @@ void Network_setActivity (Network me, integer nodeNumber, double activity) {
 
 double Network_getWeight (Network me, integer connectionNumber) {
 	try {
-		if (connectionNumber <= 0 || connectionNumber > my numberOfConnections)
-			Melder_throw (me, U": connection number (", connectionNumber, U") out of the range 1..", my numberOfConnections, U".");
+		Melder_require (connectionNumber >= 1 && connectionNumber <= my numberOfConnections,
+			me, U": connection number (", connectionNumber, U") out of the range 1..", my numberOfConnections, U".");
 		return my connections [connectionNumber]. weight;
 	} catch (MelderError) {
 		Melder_throw (me, U": weight not gotten.");
@@ -145,8 +145,8 @@ double Network_getWeight (Network me, integer connectionNumber) {
 
 void Network_setWeight (Network me, integer connectionNumber, double weight) {
 	try {
-		if (connectionNumber <= 0 || connectionNumber > my numberOfConnections)
-			Melder_throw (me, U": connection number (", connectionNumber, U") out of the range 1..", my numberOfConnections, U".");
+		Melder_require (connectionNumber >= 1 && connectionNumber <= my numberOfConnections,
+			me, U": connection number (", connectionNumber, U") out of the range 1..", my numberOfConnections, U".");
 		my connections [connectionNumber]. weight = weight;
 	} catch (MelderError) {
 		Melder_throw (me, U": weight not set.");
@@ -155,8 +155,8 @@ void Network_setWeight (Network me, integer connectionNumber, double weight) {
 
 void Network_setClamping (Network me, integer nodeNumber, bool clamped) {
 	try {
-		if (nodeNumber <= 0 || nodeNumber > my numberOfNodes)
-			Melder_throw (me, U": node number (", nodeNumber, U") out of the range 1..", my numberOfNodes, U".");
+		Melder_require (nodeNumber >= 1 && nodeNumber <= my numberOfNodes,
+			me, U": node number (", nodeNumber, U") out of the range 1..", my numberOfNodes, U".");
 		my nodes [nodeNumber]. clamped = clamped;
 	} catch (MelderError) {
 		Melder_throw (me, U": clamping not set.");
@@ -174,11 +174,13 @@ void Network_spreadActivities (Network me, integer numberOfSteps) {
 			NetworkConnection connection = & my connections [iconn];
 			NetworkNode nodeFrom = & my nodes [connection -> nodeFrom];
 			NetworkNode nodeTo = & my nodes [connection -> nodeTo];
-			double shunting = my connections [iconn]. weight >= 0.0 ? my shunting : 0.0;   // only for excitatory connections
+			const double shunting = ( my connections [iconn]. weight >= 0.0 ? my shunting : 0.0 );   // only for excitatory connections
 			if (! nodeFrom -> clamped)
-				nodeFrom -> excitation += my spreadingRate * nodeTo -> activity * (my connections [iconn]. weight - shunting * nodeFrom -> excitation);
+				nodeFrom -> excitation += my spreadingRate * nodeTo -> activity *
+						(my connections [iconn]. weight - shunting * nodeFrom -> excitation);
 			if (! nodeTo -> clamped)
-				nodeTo -> excitation += my spreadingRate * nodeFrom -> activity * (my connections [iconn]. weight - shunting * nodeTo -> excitation);
+				nodeTo -> excitation += my spreadingRate * nodeFrom -> activity *
+						(my connections [iconn]. weight - shunting * nodeTo -> excitation);
 		}
 		for (integer inode = 1; inode <= my numberOfNodes; inode ++) {
 			NetworkNode node = & my nodes [inode];
@@ -213,29 +215,35 @@ void Network_spreadActivities (Network me, integer numberOfSteps) {
 }
 
 void Network_zeroActivities (Network me, integer nodeMin, integer nodeMax) {
-	if (my numberOfNodes < 1) return;
-	if (nodeMax == 0) { nodeMin = 1; nodeMax = my numberOfNodes; }
-	if (nodeMin < 1) nodeMin = 1;
-	if (nodeMax > my numberOfNodes) nodeMax = my numberOfNodes;
-	for (integer inode = nodeMin; inode <= nodeMax; inode ++) {
-		my nodes [inode]. activity = my nodes [inode]. excitation = 0.0;
+	if (my numberOfNodes < 1)
+		return;
+	if (nodeMax == 0) {
+		nodeMin = 1;
+		nodeMax = my numberOfNodes;
 	}
+	Melder_clipLeft (1_integer, & nodeMin);
+	Melder_clipRight (& nodeMax, my numberOfNodes);
+	for (integer inode = nodeMin; inode <= nodeMax; inode ++)
+		my nodes [inode]. activity = my nodes [inode]. excitation = 0.0;
 }
 
 void Network_normalizeActivities (Network me, integer nodeMin, integer nodeMax) {
-	if (my numberOfNodes < 1) return;
-	if (nodeMax == 0) { nodeMin = 1; nodeMax = my numberOfNodes; }
-	if (nodeMin < 1) nodeMin = 1;
-	if (nodeMax > my numberOfNodes) nodeMax = my numberOfNodes;
-	if (nodeMax < nodeMin) return;
-	longdouble sum = 0.0;
-	for (integer inode = nodeMin; inode <= nodeMax; inode ++) {
-		sum += my nodes [inode]. activity;
+	if (my numberOfNodes < 1)
+		return;
+	if (nodeMax == 0) {
+		nodeMin = 1;
+		nodeMax = my numberOfNodes;
 	}
-	double average = (double) sum / (nodeMax - nodeMin + 1);
-	for (integer inode = nodeMin; inode <= nodeMax; inode ++) {
+	Melder_clipLeft (1_integer, & nodeMin);
+	Melder_clipRight (& nodeMax, my numberOfNodes);
+	if (nodeMax < nodeMin)
+		return;
+	longdouble sum = 0.0;
+	for (integer inode = nodeMin; inode <= nodeMax; inode ++)
+		sum += my nodes [inode]. activity;
+	const double average = (double) sum / (nodeMax - nodeMin + 1);
+	for (integer inode = nodeMin; inode <= nodeMax; inode ++)
 		my nodes [inode]. activity -= average;
-	}	
 }
 
 void Network_updateWeights (Network me) {
@@ -244,33 +252,36 @@ void Network_updateWeights (Network me) {
 		NetworkNode nodeFrom = & my nodes [connection -> nodeFrom];
 		NetworkNode nodeTo = & my nodes [connection -> nodeTo];
 		connection -> weight += connection -> plasticity * my learningRate *
-			(nodeFrom -> activity * nodeTo -> activity - (my instar * nodeTo -> activity + my outstar * nodeFrom -> activity + my weightLeak) * connection -> weight);
-		if (connection -> weight < my minimumWeight) connection -> weight = my minimumWeight;
-		else if (connection -> weight > my maximumWeight) connection -> weight = my maximumWeight;
+				(nodeFrom -> activity * nodeTo -> activity -
+				 (my instar * nodeTo -> activity + my outstar * nodeFrom -> activity + my weightLeak) * connection -> weight);
+		Melder_clip (my minimumWeight, & connection -> weight, my maximumWeight);
 	}
 }
 
 void Network_normalizeWeights (Network me, integer nodeMin, integer nodeMax, integer nodeFromMin, integer nodeFromMax, double newSum) {
-	if (my numberOfNodes < 1) return;
-	if (nodeMax == 0) { nodeMin = 1; nodeMax = my numberOfNodes; }
-	if (nodeMin < 1) nodeMin = 1;
-	if (nodeMax > my numberOfNodes) nodeMax = my numberOfNodes;
-	if (nodeMax < nodeMin) return;
+	if (my numberOfNodes < 1)
+		return;
+	if (nodeMax == 0) {
+		nodeMin = 1;
+		nodeMax = my numberOfNodes;
+	}
+	Melder_clipLeft (1_integer, & nodeMin);
+	Melder_clipRight (& nodeMax, my numberOfNodes);
+	if (nodeMax < nodeMin)
+		return;
 	for (integer inode = nodeMin; inode <= nodeMax; inode ++) {
 		longdouble sum = 0.0;
 		for (integer iconn = 1; iconn <= my numberOfConnections; iconn ++) {
 			NetworkConnection connection = & my connections [iconn];
-			if (connection -> nodeTo == inode && connection -> nodeFrom >= nodeFromMin && connection -> nodeFrom <= nodeFromMax) {
+			if (connection -> nodeTo == inode && connection -> nodeFrom >= nodeFromMin && connection -> nodeFrom <= nodeFromMax)
 				sum += connection -> weight;
-			}
 		}
 		if (sum != 0.0) {
-			double factor = newSum / (double) sum;
+			const double factor = newSum / (double) sum;
 			for (integer iconn = 1; iconn <= my numberOfConnections; iconn ++) {
 				NetworkConnection connection = & my connections [iconn];
-				if (connection -> nodeTo == inode && connection -> nodeFrom >= nodeFromMin && connection -> nodeFrom <= nodeFromMax) {
+				if (connection -> nodeTo == inode && connection -> nodeFrom >= nodeFromMin && connection -> nodeFrom <= nodeFromMax)
 					connection -> weight *= factor;
-				}
 			}
 		}
 	}
@@ -284,12 +295,12 @@ autoNetwork Network_create_rectangle (double spreadingRate, enum kNetwork_activi
 {
 	try {
 		autoNetwork me = Network_create (spreadingRate, activityClippingRule, minimumActivity, maximumActivity, activityLeak,
-			learningRate, minimumWeight, maximumWeight, weightLeak,
-			0.0, numberOfColumns, 0.0, numberOfRows, numberOfRows * numberOfColumns,
-			numberOfRows * (numberOfColumns - 1) + numberOfColumns * (numberOfRows - 1));
+				learningRate, minimumWeight, maximumWeight, weightLeak,
+				0.0, numberOfColumns, 0.0, numberOfRows, numberOfRows * numberOfColumns,
+				numberOfRows * (numberOfColumns - 1) + numberOfColumns * (numberOfRows - 1));
 		/*
-		 * Define nodes.
-		 */
+			Define nodes.
+		*/
 		for (integer inode = 1; inode <= my numberOfNodes; inode ++) {
 			NetworkNode node = & my nodes [inode];
 			node -> x = (inode - 1) % numberOfColumns + 0.5;
@@ -298,8 +309,8 @@ autoNetwork Network_create_rectangle (double spreadingRate, enum kNetwork_activi
 			node -> activity = NUMrandomUniform (my minimumActivity, my maximumActivity);
 		}
 		/*
-		 * Define connections.
-		 */
+			Define connections.
+		*/
 		integer iconn = 0;
 		for (integer irow = 1; irow <= numberOfRows; irow ++) {
 			for (integer icol = 1; icol <= numberOfColumns - 1; icol ++) {
@@ -334,12 +345,12 @@ autoNetwork Network_create_rectangle_vertical (double spreadingRate, enum kNetwo
 {
 	try {
 		autoNetwork me = Network_create (spreadingRate, activityClippingRule, minimumActivity, maximumActivity, activityLeak,
-			learningRate, minimumWeight, maximumWeight, weightLeak,
-			0.0, numberOfColumns, 0.0, numberOfRows, numberOfRows * numberOfColumns,
-			numberOfColumns * numberOfColumns * (numberOfRows - 1));
+				learningRate, minimumWeight, maximumWeight, weightLeak,
+				0.0, numberOfColumns, 0.0, numberOfRows, numberOfRows * numberOfColumns,
+				numberOfColumns * numberOfColumns * (numberOfRows - 1));
 		/*
-		 * Define nodes.
-		 */
+			Define nodes.
+		*/
 		for (integer inode = 1; inode <= my numberOfNodes; inode ++) {
 			NetworkNode node = & my nodes [inode];
 			node -> x = (inode - 1) % numberOfColumns + 0.5;
@@ -348,8 +359,8 @@ autoNetwork Network_create_rectangle_vertical (double spreadingRate, enum kNetwo
 			node -> activity = NUMrandomUniform (my minimumActivity, my maximumActivity);
 		}
 		/*
-		 * Define connections.
-		 */
+			Define connections.
+		*/
 		integer iconn = 0;
 		for (integer icol = 1; icol <= numberOfColumns; icol ++) {
 			for (integer jcol = 1; jcol <= numberOfColumns; jcol ++) {
@@ -374,35 +385,35 @@ void Network_draw (Network me, Graphics graphics, bool useColour) {
 	Graphics_setInner (graphics);
 	Graphics_setWindow (graphics, my xmin, my xmax, my ymin, my ymax);
 	if (useColour) {
-		Graphics_setColour (graphics, Graphics_SILVER);
+		Graphics_setColour (graphics, Melder_SILVER);
 		Graphics_fillRectangle (graphics, my xmin, my xmax, my ymin, my ymax);
 	}
 	/*
-	 * Draw connections.
-	 */
+		Draw connections.
+	*/
 	for (integer iconn = 1; iconn <= my numberOfConnections; iconn ++) {
 		NetworkConnection conn = & my connections [iconn];
 		if (fabs (conn -> weight) >= 0.01) {
 			NetworkNode nodeFrom = & my nodes [conn -> nodeFrom];
 			NetworkNode nodeTo = & my nodes [conn -> nodeTo];
 			Graphics_setLineWidth (graphics, fabs (conn -> weight) * 6.0);
-			Graphics_setColour (graphics, conn -> weight < 0.0 ? ( useColour ? Graphics_WHITE : Graphics_SILVER ) : Graphics_BLACK);
+			Graphics_setColour (graphics, conn -> weight < 0.0 ? ( useColour ? Melder_WHITE : Melder_SILVER ) : Melder_BLACK);
 			Graphics_line (graphics, nodeFrom -> x, nodeFrom -> y, nodeTo -> x, nodeTo -> y);
 		}
 	}
 	Graphics_setLineWidth (graphics, 1.0);
 	/*
-	 * Draw the backgrounds of the nodes.
-	 */
+		Draw the backgrounds of the nodes.
+	*/
 	for (integer inode = 1; inode <= my numberOfNodes; inode ++) {
 		NetworkNode node = & my nodes [inode];
-		Graphics_setColour (graphics, useColour ? Graphics_SILVER : Graphics_WHITE);
+		Graphics_setColour (graphics, useColour ? Melder_SILVER : Melder_WHITE);
 		Graphics_fillCircle_mm (graphics, node -> x, node -> y, 5.0);
 	}
 	/*
-	 * Draw the edges of the nodes.
-	 */
-	Graphics_setColour (graphics, Graphics_BLACK);
+		Draw the edges of the nodes.
+	*/
+	Graphics_setColour (graphics, Melder_BLACK);
 	Graphics_setLineWidth (graphics, 2.0);
 	for (integer inode = 1; inode <= my numberOfNodes; inode ++) {
 		NetworkNode node = & my nodes [inode];
@@ -410,21 +421,22 @@ void Network_draw (Network me, Graphics graphics, bool useColour) {
 		Graphics_circle_mm (graphics, node -> x, node -> y, 5.2);
 	}
 	/*
-	 * Draw the activities of the nodes.
-	 */
+		Draw the activities of the nodes.
+	*/
 	for (integer inode = 1; inode <= my numberOfNodes; inode ++) {
 		NetworkNode node = & my nodes [inode];
 		double activity = fabs (node -> activity);
-		if (activity >= 1.0) activity = sqrt (activity);
+		if (activity >= 1.0)
+			activity = sqrt (activity);
 		double diameter = activity * 5.0;
 		if (diameter != 0.0) {
 			Graphics_setColour (graphics,
-				useColour ? ( node -> activity < 0.0 ? Graphics_BLUE : Graphics_RED )
-				: ( node -> activity < 0.0 ? Graphics_SILVER : Graphics_BLACK));
+					useColour ? ( node -> activity < 0.0 ? Melder_BLUE : Melder_RED )
+					: ( node -> activity < 0.0 ? Melder_SILVER : Melder_BLACK));
 			Graphics_fillCircle_mm (graphics, node -> x, node -> y, diameter);
 		}
 	}
-	Graphics_setColour (graphics, Graphics_BLACK);
+	Graphics_setColour (graphics, Melder_BLACK);
 	Graphics_setLineWidth (graphics, saveLineWidth);
 	Graphics_setLineType (graphics, Graphics_DRAWN);
 	Graphics_unsetInner (graphics);
@@ -432,9 +444,10 @@ void Network_draw (Network me, Graphics graphics, bool useColour) {
 
 void Network_addNode (Network me, double x, double y, double activity, bool clamped) {
 	try {
-		integer numberOfNodes = my numberOfNodes;
-		NUMvector_append (& my nodes, 1, & numberOfNodes);
-		my numberOfNodes = numberOfNodes;
+		Melder_assert (my nodes.size == my numberOfNodes);
+		my nodes.resize (my numberOfNodes + 1);
+		my numberOfNodes += 1;   // maintain invariant
+		Melder_assert (my numberOfNodes == my nodes.size);
 		my nodes [my numberOfNodes]. x = x;
 		my nodes [my numberOfNodes]. y = y;
 		my nodes [my numberOfNodes]. activity = my nodes [my numberOfNodes]. excitation = activity;
@@ -446,9 +459,10 @@ void Network_addNode (Network me, double x, double y, double activity, bool clam
 
 void Network_addConnection (Network me, integer nodeFrom, integer nodeTo, double weight, double plasticity) {
 	try {
-		integer numberOfConnections = my numberOfConnections;
-		NUMvector_append (& my connections, 1, & numberOfConnections);
-		my numberOfConnections = numberOfConnections;
+		Melder_assert (my connections.size == my numberOfConnections);
+		my connections.resize (my numberOfConnections + 1);
+		my numberOfConnections += 1;   // maintain invariant
+		Melder_assert (my numberOfConnections == my connections.size);
 		my connections [my numberOfConnections]. nodeFrom = nodeFrom;
 		my connections [my numberOfConnections]. nodeTo = nodeTo;
 		my connections [my numberOfConnections]. weight = weight;
@@ -492,14 +506,16 @@ autoTable Network_nodes_downto_Table (Network me, integer fromNodeNumber, intege
 	bool includeActivity, bool includeExcitation, int activityDecimals)
 {
 	try {
-		if (fromNodeNumber < 1) fromNodeNumber = 1;
-		if (toNodeNumber > my numberOfNodes) toNodeNumber = my numberOfNodes;
-		if (fromNodeNumber > toNodeNumber)
-			fromNodeNumber = 1, toNodeNumber = my numberOfNodes;
+		Melder_clipLeft (1_integer, & fromNodeNumber);
+		Melder_clipRight (& toNodeNumber, my numberOfNodes);
+		if (fromNodeNumber > toNodeNumber) {
+			fromNodeNumber = 1;
+			toNodeNumber = my numberOfNodes;
+		}
 		integer numberOfNodes = toNodeNumber - fromNodeNumber + 1;
 		Melder_assert (numberOfNodes >= 1);
 		autoTable thee = Table_createWithoutColumnNames (numberOfNodes,
-			includeNodeNumbers + includeX + includeY + includeClamped + includeActivity + includeExcitation);
+				includeNodeNumbers + includeX + includeY + includeClamped + includeActivity + includeExcitation);
 		integer icol = 0;
 		if (includeNodeNumbers) Table_setColumnLabel (thee.get(), ++ icol, U"node");
 		if (includeX)           Table_setColumnLabel (thee.get(), ++ icol, U"x");
@@ -531,7 +547,7 @@ void Network_listNodes (Network me, integer fromNodeNumber, integer toNodeNumber
 {
 	try {
 		autoTable table = Network_nodes_downto_Table (me, fromNodeNumber, toNodeNumber, includeNodeNumbers,
-			includeX, includeY, positionDecimals, includeClamped, includeActivity, includeExcitation, activityDecimals);
+				includeX, includeY, positionDecimals, includeClamped, includeActivity, includeExcitation, activityDecimals);
 		Table_list (table.get(), false);
 	} catch (MelderError) {
 		Melder_throw (me, U": not listed.");
